@@ -527,6 +527,30 @@ class SpreadsheetEntryTest(unittest.TestCase):
                      'http://spreadsheets.google.com/feeds/spreadsheets'
                      '/private/full/key')
 
+  def test_get_spreadsheet_key(self):
+    self.assertEqual(self.spreadsheet.get_spreadsheet_key(), 'key')
+    # Change the value of the self link.
+    self.spreadsheet.id.text = '42'
+    self.assertEqual(self.spreadsheet.GetSpreadsheetKey(), '42')
+
+
+class WorksheetEntryTest(unittest.TestCase):
+
+  def setUp(self):
+    self.worksheets = atom.core.parse(
+        WORKSHEETS_FEED, gdata.spreadsheets.data.WorksheetsFeed)
+
+  def test_check_parsing(self):
+    self.assertEqual(len(self.worksheets.entry), 1)
+    self.assertEqual(self.worksheets.entry[0].get_id(),
+        'http://spreadsheets.google.com/feeds/worksheets/0/private/full/1')
+
+  def test_get_worksheet_id(self):
+    self.assertEqual(self.worksheets.entry[0].get_worksheet_id(), '1')
+    self.worksheets.entry[0].id.text = '////spam'
+    self.assertEqual(self.worksheets.entry[0].GetWorksheetId(), 'spam')
+
+
 
 class ListEntryTest(unittest.TestCase):
 
@@ -542,16 +566,16 @@ class ListEntryTest(unittest.TestCase):
     row.set_value('x', 'Test')
     self.assertEqual(row.get_value('x'), 'Test')
     row_xml = str(row)
-    self.assertTrue(row_xml.find(':x') > -1)
-    self.assertTrue(row_xml.find('>Test</') > -1)
-    self.assertTrue(row_xml.find(':hours') > -1)
-    self.assertTrue(row_xml.find('>3</') > -1)
-    self.assertTrue(row_xml.find(':ipm') > -1)
-    self.assertTrue(row_xml.find('>1</') > -1)
-    self.assertTrue(row_xml.find(':items') > -1)
-    self.assertTrue(row_xml.find('>60</') > -1)
-    self.assertTrue(row_xml.find(':name') > -1)
-    self.assertTrue(row_xml.find('>Lizzy</') > -1)
+    self.assert_(row_xml.find(':x') > -1)
+    self.assert_(row_xml.find('>Test</') > -1)
+    self.assert_(row_xml.find(':hours') > -1)
+    self.assert_(row_xml.find('>3</') > -1)
+    self.assert_(row_xml.find(':ipm') > -1)
+    self.assert_(row_xml.find('>1</') > -1)
+    self.assert_(row_xml.find(':items') > -1)
+    self.assert_(row_xml.find('>60</') > -1)
+    self.assert_(row_xml.find(':name') > -1)
+    self.assert_(row_xml.find('>Lizzy</') > -1)
     self.assertEqual(row_xml.find(':zzz'), -1)
     self.assertEqual(row_xml.find('>foo</'), -1)
 
@@ -576,6 +600,68 @@ class ListEntryTest(unittest.TestCase):
     self.assertEqual(row.content.text, 'Hours: 10, Items: 2, IPM: 0.0033')
 
 
+class RecordEntryTest(unittest.TestCase):
+
+  def setUp(self):
+    self.records = atom.core.parse(
+        RECORDS_FEED, gdata.spreadsheets.data.RecordsFeed)
+
+  def test_get_by_index(self):
+    self.assertEqual(self.records.entry[0].field[0].index, 'B')
+    self.assertEqual(self.records.entry[0].field[0].name, 'Birthday')
+    self.assertEqual(self.records.entry[0].field[0].text, '2/10/1785')
+    self.assertEqual(self.records.entry[0].value_for_index('B'), '2/10/1785')
+    self.assertRaises(gdata.spreadsheets.data.FieldMissing,
+                      self.records.entry[0].ValueForIndex, 'E')
+    self.assertEqual(self.records.entry[1].value_for_index('D'), 'Yes')
+
+  def test_get_by_name(self):
+    self.assertEqual(self.records.entry[0].ValueForName('Birthday'),
+                     '2/10/1785')
+    self.assertRaises(gdata.spreadsheets.data.FieldMissing,
+                      self.records.entry[0].value_for_name, 'Foo')
+    self.assertEqual(self.records.entry[1].value_for_name('Age'), '22')
+
+
+class BatchRequestTest(unittest.TestCase):
+
+  def setUp(self):
+    self.feed = gdata.spreadsheets.data.build_batch_cells_update('skey', 'wid')
+
+  def test_builder(self):
+    self.assertEqual(len(self.feed.link), 1)
+    self.assertEqual(self.feed.link[0].rel, 'edit')
+    self.assertEqual(self.feed.link[0].href,
+        'https://spreadsheets.google.com/feeds/cells/skey/wid/'
+        'private/full/batch')
+    self.assertEqual(self.feed.id.text,
+        'https://spreadsheets.google.com/feeds/cells/skey/wid/'
+        'private/full')
+    self.assertEqual(len(self.feed.entry), 0)
+
+  def test_set_cell(self):
+    self.feed.add_set_cell(1, 2, 'value')
+    self.assertEqual(len(self.feed.entry), 1)
+    self.assertEqual(self.feed.entry[0].id.text,
+        'https://spreadsheets.google.com/feeds/cells/skey/wid/private/'
+        'full/R1C2')
+    self.assertEqual(self.feed.entry[0].cell.row, '1')
+    self.assertEqual(self.feed.entry[0].cell.col, '2')
+    self.assertEqual(self.feed.entry[0].cell.input_value, 'value')
+    self.assertEqual(self.feed.entry[0].batch_operation.type, 'update')
+    self.assertEqual(self.feed.entry[0].batch_id.text, '0')
+    self.feed.add_set_cell(3, 1, 'spam')
+    self.assertEqual(len(self.feed.entry), 2)
+    self.assertEqual(self.feed.entry[1].id.text,
+        'https://spreadsheets.google.com/feeds/cells/skey/wid/private/'
+        'full/R3C1')
+    self.assertEqual(self.feed.entry[1].cell.row, '3')
+    self.assertEqual(self.feed.entry[1].cell.col, '1')
+    self.assertEqual(self.feed.entry[1].cell.input_value, 'spam')
+    self.assertEqual(self.feed.entry[1].batch_operation.type, 'update')
+    self.assertEqual(self.feed.entry[1].batch_id.text, '1')
+
+
 class DataClassSanityTest(unittest.TestCase):
 
   def test_basic_element_structure(self):
@@ -601,7 +687,7 @@ class DataClassSanityTest(unittest.TestCase):
 
 def suite():
   return conf.build_suite([SpreadsheetEntryTest, DataClassSanityTest,
-                           ListEntryTest])
+                           ListEntryTest, RecordEntryTest])
 
 
 if __name__ == '__main__':
